import '@polkadot/api-base/types/consts';
import type { ApiTypes, AugmentedConst } from '@polkadot/api-base/types';
import type { Option, U8aFixed, Vec, bool, u128, u16, u32, u64, u8 } from '@polkadot/types-codec';
import type { Codec, ITuple } from '@polkadot/types-codec/types';
import type { H160, Perbill, Permill } from '@polkadot/types/interfaces/runtime';
import type { FrameSupportPalletId, FrameSystemLimitsBlockLength, FrameSystemLimitsBlockWeights, PalletReferendaTrackInfo, SpVersionRuntimeVersion, SpWeightsRuntimeDbWeight, SpWeightsWeightV2Weight, StagingXcmV3MultiLocation, UpDataStructsCollectionLimits } from '@polkadot/types/lookup';
export type __AugmentedConst<ApiType extends ApiTypes> = AugmentedConst<ApiType>;
declare module '@polkadot/api-base/types/consts' {
    interface AugmentedConsts<ApiType extends ApiTypes> {
        appPromotion: {
            /**
             * Freeze identifier used by the pallet
             **/
            freezeIdentifier: U8aFixed & AugmentedConst<ApiType>;
            /**
             * Rate of return for interval in blocks defined in `RecalculationInterval`.
             **/
            intervalIncome: Perbill & AugmentedConst<ApiType>;
            /**
             * Decimals for the `Currency`.
             **/
            nominal: u128 & AugmentedConst<ApiType>;
            /**
             * The app's pallet id, used for deriving its sovereign account address.
             **/
            palletId: FrameSupportPalletId & AugmentedConst<ApiType>;
            /**
             * In parachain blocks.
             **/
            pendingInterval: u32 & AugmentedConst<ApiType>;
            /**
             * In relay blocks.
             **/
            recalculationInterval: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        balances: {
            /**
             * The minimum amount required to keep an account open. MUST BE GREATER THAN ZERO!
             *
             * If you *really* need it to be zero, you can enable the feature `insecure_zero_ed` for
             * this pallet. However, you do so at your own risk: this will open up a major DoS vector.
             * In case you have multiple sources of provider references, you may also get unexpected
             * behaviour if you set this to zero.
             *
             * Bottom line: Do yourself a favour and make it at least one!
             **/
            existentialDeposit: u128 & AugmentedConst<ApiType>;
            /**
             * The maximum number of individual freeze locks that can exist on an account at any time.
             **/
            maxFreezes: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of holds that can exist on an account at any time.
             **/
            maxHolds: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of locks that should exist on an account.
             * Not strictly enforced, but used for weight estimation.
             **/
            maxLocks: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of named reserves that can exist on an account.
             **/
            maxReserves: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        common: {
            /**
             * Maximum admins per collection.
             **/
            collectionAdminsLimit: u32 & AugmentedConst<ApiType>;
            /**
             * Set price to create a collection.
             **/
            collectionCreationPrice: u128 & AugmentedConst<ApiType>;
            /**
             * Address under which the CollectionHelper contract would be available.
             **/
            contractAddress: H160 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        configuration: {
            appPromotionDailyRate: Perbill & AugmentedConst<ApiType>;
            dayRelayBlocks: u32 & AugmentedConst<ApiType>;
            defaultCollatorSelectionKickThreshold: u32 & AugmentedConst<ApiType>;
            defaultCollatorSelectionLicenseBond: u128 & AugmentedConst<ApiType>;
            defaultCollatorSelectionMaxCollators: u32 & AugmentedConst<ApiType>;
            defaultMinGasPrice: u64 & AugmentedConst<ApiType>;
            defaultWeightToFeeCoefficient: u64 & AugmentedConst<ApiType>;
            maxXcmAllowedLocations: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        council: {
            /**
             * The maximum weight of a dispatch call that can be proposed and executed.
             **/
            maxProposalWeight: SpWeightsWeightV2Weight & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        democracy: {
            /**
             * Period in blocks where an external proposal may not be re-submitted after being vetoed.
             **/
            cooloffPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * The period between a proposal being approved and enacted.
             *
             * It should generally be a little more than the unstake period to ensure that
             * voting stakers have an opportunity to remove themselves from the system in the case
             * where they are on the losing side of a vote.
             **/
            enactmentPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * Minimum voting period allowed for a fast-track referendum.
             **/
            fastTrackVotingPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * Indicator for whether an emergency origin is even allowed to happen. Some chains may
             * want to set this permanently to `false`, others may want to condition it on things such
             * as an upgrade having happened recently.
             **/
            instantAllowed: bool & AugmentedConst<ApiType>;
            /**
             * How often (in blocks) new public referenda are launched.
             **/
            launchPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of items which can be blacklisted.
             **/
            maxBlacklisted: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of deposits a public proposal may have at any time.
             **/
            maxDeposits: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of public proposals that can exist at any time.
             **/
            maxProposals: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of votes for an account.
             *
             * Also used to compute weight, an overly big value can
             * lead to extrinsic with very big weight: see `delegate` for instance.
             **/
            maxVotes: u32 & AugmentedConst<ApiType>;
            /**
             * The minimum amount to be used as a deposit for a public referendum proposal.
             **/
            minimumDeposit: u128 & AugmentedConst<ApiType>;
            /**
             * The minimum period of vote locking.
             *
             * It should be no shorter than enactment period to ensure that in the case of an approval,
             * those successful voters are locked into the consequences that their votes entail.
             **/
            voteLockingPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * How often (in blocks) to check for new votes.
             **/
            votingPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        evmContractHelpers: {
            /**
             * Address, under which magic contract will be available
             **/
            contractAddress: H160 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        fellowshipReferenda: {
            /**
             * Quantization level for the referendum wakeup scheduler. A higher number will result in
             * fewer storage reads/writes needed for smaller voters, but also result in delays to the
             * automatic referendum status changes. Explicit servicing instructions are unaffected.
             **/
            alarmInterval: u32 & AugmentedConst<ApiType>;
            /**
             * Maximum size of the referendum queue for a single track.
             **/
            maxQueued: u32 & AugmentedConst<ApiType>;
            /**
             * The minimum amount to be used as a deposit for a public referendum proposal.
             **/
            submissionDeposit: u128 & AugmentedConst<ApiType>;
            /**
             * Information concerning the different referendum tracks.
             **/
            tracks: Vec<ITuple<[u16, PalletReferendaTrackInfo]>> & AugmentedConst<ApiType>;
            /**
             * The number of blocks after submission that a referendum must begin being decided by.
             * Once this passes, then anyone may cancel the referendum.
             **/
            undecidingTimeout: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        identity: {
            /**
             * The amount held on deposit for a registered identity
             **/
            basicDeposit: u128 & AugmentedConst<ApiType>;
            /**
             * The amount held on deposit per additional field for a registered identity.
             **/
            fieldDeposit: u128 & AugmentedConst<ApiType>;
            /**
             * Maximum number of additional fields that may be stored in an ID. Needed to bound the I/O
             * required to access an identity, but can be pretty high.
             **/
            maxAdditionalFields: u32 & AugmentedConst<ApiType>;
            /**
             * Maxmimum number of registrars allowed in the system. Needed to bound the complexity
             * of, e.g., updating judgements.
             **/
            maxRegistrars: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum number of sub-accounts allowed per identified account.
             **/
            maxSubAccounts: u32 & AugmentedConst<ApiType>;
            /**
             * The amount held on deposit for a registered subaccount. This should account for the fact
             * that one storage item's value will increase by the size of an account ID, and there will
             * be another trie item whose value is the size of an account ID plus 32 bytes.
             **/
            subAccountDeposit: u128 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        inflation: {
            /**
             * Number of blocks that pass between treasury balance updates due to inflation
             **/
            inflationBlockInterval: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        scheduler: {
            /**
             * The maximum weight that may be scheduled per block for any dispatchables.
             **/
            maximumWeight: SpWeightsWeightV2Weight & AugmentedConst<ApiType>;
            /**
             * The maximum number of scheduled calls in the queue for a single block.
             *
             * NOTE:
             * + Dependent pallets' benchmarks might require a higher limit for the setting. Set a
             * higher limit under `runtime-benchmarks` feature.
             **/
            maxScheduledPerBlock: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        stateTrieMigration: {
            /**
             * Maximal number of bytes that a key can have.
             *
             * FRAME itself does not limit the key length.
             * The concrete value must therefore depend on your storage usage.
             * A [`frame_support::storage::StorageNMap`] for example can have an arbitrary number of
             * keys which are then hashed and concatenated, resulting in arbitrarily long keys.
             *
             * Use the *state migration RPC* to retrieve the length of the longest key in your
             * storage: <https://github.com/paritytech/substrate/issues/11642>
             *
             * The migration will halt with a `Halted` event if this value is too small.
             * Since there is no real penalty from over-estimating, it is advised to use a large
             * value. The default is 512 byte.
             *
             * Some key lengths for reference:
             * - [`frame_support::storage::StorageValue`]: 32 byte
             * - [`frame_support::storage::StorageMap`]: 64 byte
             * - [`frame_support::storage::StorageDoubleMap`]: 96 byte
             *
             * For more info see
             * <https://www.shawntabrizi.com/substrate/querying-substrate-storage-via-rpc/>
             **/
            maxKeyLen: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        system: {
            /**
             * Maximum number of block number to block hash mappings to keep (oldest pruned first).
             **/
            blockHashCount: u32 & AugmentedConst<ApiType>;
            /**
             * The maximum length of a block (in bytes).
             **/
            blockLength: FrameSystemLimitsBlockLength & AugmentedConst<ApiType>;
            /**
             * Block & extrinsics weights: base values and limits.
             **/
            blockWeights: FrameSystemLimitsBlockWeights & AugmentedConst<ApiType>;
            /**
             * The weight of runtime database operations the runtime can invoke.
             **/
            dbWeight: SpWeightsRuntimeDbWeight & AugmentedConst<ApiType>;
            /**
             * The designated SS58 prefix of this chain.
             *
             * This replaces the "ss58Format" property declared in the chain spec. Reason is
             * that the runtime should know about the prefix in order to make use of it as
             * an identifier of the chain.
             **/
            ss58Prefix: u16 & AugmentedConst<ApiType>;
            /**
             * Get the chain's current version.
             **/
            version: SpVersionRuntimeVersion & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        technicalCommittee: {
            /**
             * The maximum weight of a dispatch call that can be proposed and executed.
             **/
            maxProposalWeight: SpWeightsWeightV2Weight & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        timestamp: {
            /**
             * The minimum period between blocks.
             *
             * Be aware that this is different to the *expected* period that the block production
             * apparatus provides. Your chosen consensus system will generally work with this to
             * determine a sensible block time. For example, in the Aura pallet it will be double this
             * period on default settings.
             **/
            minimumPeriod: u64 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        transactionPayment: {
            /**
             * A fee mulitplier for `Operational` extrinsics to compute "virtual tip" to boost their
             * `priority`
             *
             * This value is multipled by the `final_fee` to obtain a "virtual tip" that is later
             * added to a tip component in regular `priority` calculations.
             * It means that a `Normal` transaction can front-run a similarly-sized `Operational`
             * extrinsic (with no tip), by including a tip value greater than the virtual tip.
             *
             * ```rust,ignore
             * // For `Normal`
             * let priority = priority_calc(tip);
             *
             * // For `Operational`
             * let virtual_tip = (inclusion_fee + tip) * OperationalFeeMultiplier;
             * let priority = priority_calc(tip + virtual_tip);
             * ```
             *
             * Note that since we use `final_fee` the multiplier applies also to the regular `tip`
             * sent with the transaction. So, not only does the transaction get a priority bump based
             * on the `inclusion_fee`, but we also amplify the impact of tips applied to `Operational`
             * transactions.
             **/
            operationalFeeMultiplier: u8 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        treasury: {
            /**
             * Percentage of spare funds (if any) that are burnt per spend period.
             **/
            burn: Permill & AugmentedConst<ApiType>;
            /**
             * The maximum number of approvals that can wait in the spending queue.
             *
             * NOTE: This parameter is also used within the Bounties Pallet extension if enabled.
             **/
            maxApprovals: u32 & AugmentedConst<ApiType>;
            /**
             * The treasury's pallet id, used for deriving its sovereign account ID.
             **/
            palletId: FrameSupportPalletId & AugmentedConst<ApiType>;
            /**
             * The period during which an approved treasury spend has to be claimed.
             **/
            payoutPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * Fraction of a proposal's value that should be bonded in order to place the proposal.
             * An accepted proposal gets these back. A rejected proposal does not.
             **/
            proposalBond: Permill & AugmentedConst<ApiType>;
            /**
             * Maximum amount of funds that should be placed in a deposit for making a proposal.
             **/
            proposalBondMaximum: Option<u128> & AugmentedConst<ApiType>;
            /**
             * Minimum amount of funds that should be placed in a deposit for making a proposal.
             **/
            proposalBondMinimum: u128 & AugmentedConst<ApiType>;
            /**
             * Period between successive spends.
             **/
            spendPeriod: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        unique: {
            /**
             * Maximum admins per collection.
             **/
            collectionAdminsLimit: u32 & AugmentedConst<ApiType>;
            /**
             * Default FT collection limit.
             **/
            ftDefaultCollectionLimits: UpDataStructsCollectionLimits & AugmentedConst<ApiType>;
            /**
             * Maximal length of a collection description.
             **/
            maxCollectionDescriptionLength: u32 & AugmentedConst<ApiType>;
            /**
             * Maximal length of a collection name.
             **/
            maxCollectionNameLength: u32 & AugmentedConst<ApiType>;
            /**
             * Maximum size for all collection properties.
             **/
            maxCollectionPropertiesSize: u32 & AugmentedConst<ApiType>;
            /**
             * A maximum number of token properties.
             **/
            maxPropertiesPerItem: u32 & AugmentedConst<ApiType>;
            /**
             * Maximal length of a property key.
             **/
            maxPropertyKeyLength: u32 & AugmentedConst<ApiType>;
            /**
             * Maximal length of a property value.
             **/
            maxPropertyValueLength: u32 & AugmentedConst<ApiType>;
            /**
             * Maximal length of a token prefix.
             **/
            maxTokenPrefixLength: u32 & AugmentedConst<ApiType>;
            /**
             * Maximum size of all token properties.
             **/
            maxTokenPropertiesSize: u32 & AugmentedConst<ApiType>;
            /**
             * A maximum number of levels of depth in the token nesting tree.
             **/
            nestingBudget: u32 & AugmentedConst<ApiType>;
            /**
             * Default NFT collection limit.
             **/
            nftDefaultCollectionLimits: UpDataStructsCollectionLimits & AugmentedConst<ApiType>;
            /**
             * Default RFT collection limit.
             **/
            rftDefaultCollectionLimits: UpDataStructsCollectionLimits & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        utility: {
            /**
             * The limit on the number of batched calls.
             **/
            batchedCallsLimit: u32 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        vesting: {
            /**
             * The minimum amount transferred to call `vested_transfer`.
             **/
            minVestedTransfer: u128 & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
        xTokens: {
            /**
             * Base XCM weight.
             *
             * The actually weight for an XCM message is `T::BaseXcmWeight +
             * T::Weigher::weight(&msg)`.
             **/
            baseXcmWeight: SpWeightsWeightV2Weight & AugmentedConst<ApiType>;
            /**
             * Self chain location.
             **/
            selfLocation: StagingXcmV3MultiLocation & AugmentedConst<ApiType>;
            /**
             * Generic const
             **/
            [key: string]: Codec;
        };
    }
}
